behavior missionTimer
{
timeOut = 858;
}
# 
# depth envelope
behavior depthEnvelope
{
minDepth = 0;
maxDepth = 50;
abortDepth = 60;
minAltitude = 15;
abortAltitude = 10;
}
# acquire gps fix 
behavior getgps
{
duration = 600;
minHits = 10;
abortOnTimeout = True;
}
# 
# ascend behavior 
behavior ascend
{
duration = 400;
horizontalMode = rudder;
horizontal = 3.000000;
pitch = 45.000000;
speed = 1.500000;
endDepth = 2.000000;
}
behavior cathx
{
    duration = 1;
    capture = 0;
}
behavior cathx
{
    duration = 1;
    capture = 1;
}
behavior cathx
{
    duration = 1;
    profile = 0;
    capture = 0;
}
# East End
behavior waypoint_bottom
{
latitude = 36.696459;
longitude = -121.936001;
duration = 561;
depth = 35;
speed = 1.500000;
}
# Head North
behavior waypoint_bottom
{
latitude = 36.696486;
longitude = -121.940635;
duration = 24;
depth = 35;
speed = 1.5;
}
# West End
behavior waypoint_bottom
{
latitude = 36.696324;
longitude = -121.940646;
duration = 224;
depth = 35.000000;
speed = 1.500000;
}
behavior cathx
{
    duration = 1;
    capture = 1;
}
behavior cathx
{
    duration = 1;
    profile = 4;
    capture = 0;
}
#
# Step down 5m after traveling 250m.
behavior waypoint_bottom
{
latitude = 36.696297;
longitude = -121.938810;
duration = 338;
depth = 30.000000;
speed = 1.500000;
}
#
# East End
behavior cathx
{
    duration = 1;
    capture = 1;
}
behavior cathx
{
    duration = 1;
    profile = 3;
    capture = 0;
}
behavior waypoint_bottom
{
latitude = 36.696270;
longitude = -121.936012;
duration = 667;
depth = 30.000000;
speed = 1.500000;
}
behavior cathx
{
    duration = 1;
    capture = 1;
}
behavior cathx
{
    duration = 1;
    profile = 2;
    capture = 0;
}
behavior descend
{
horizontalMode = rudder;
horizontal = 3.0;
pitch = -35.000000;
speed = 1.500000;
maxDepth = 25;
minAltitude = 50.000000;
duration = 300;
}
behavior cathx
{
    duration = 1;
    capture = 1;
}
behavior cathx
{
    duration = 1;
    profile = 1;
    capture = 0;
}
# North West
behavior waypoint_bottom
{
latitude = 36.696270;
longitude = -121.936012;
duration = 667;
depth = 15.000000;
speed = 1.500000;
}
# 
# Descend behavior 
behavior descend
{
horizontalMode = heading;
horizontal = 180.0;
pitch = -35.000000;
speed = 1.500000;
maxDepth = 15.000000;
minAltitude = 15.;
duration = 300;
}
# 
# setpoint on surface to gather momentum 
behavior setpoint
{
duration = 30;
heading = 180.0;
speed = 1.500000;
verticalMode = pitch;
pitch = 0;
}
behavior cathx
{
    id = 1;
    duration = 1;
    profile = 0;
    capture = 0;
}
# 
# acquire gps fix 
behavior getgps
{
duration = 600;
minHits = 10;
abortOnTimeout = True;
}
